.logo {
  font-family: 'Clicker Script', cursive;
}

.logo a {
  color: #212529;
  text-decoration: none;
}

footer {
  font-size: .9rem;
}

footer a {
  color: #212529;
}


.btn-student {
  color: #fff;
  background-color: #91afb6;
  border-color: #91afb6;
}

.btn-student:hover,
.btn-student:active {
  color: #fff;
  background-color: #608993;
  border-color: #608993;
}



.has-danger .radio,
.has-danger .checkbox {
  color: #dc3545;
}

.has-danger .invalid-feedback {
  display: block;
}

body {
  background-color: #c2d4d8;
}
