{% extends 'quiz/base.html' %}

{# load crispy_forms_tags #}

{% block content %}
  <h2 class="mb-3">Update your interests</h2>
  <form method="post" novalidate>
    {% csrf_token %}
    {{ form }}
    <button type="submit" class="btn btn-success">Save changes</button>
    <a href="{% url 'quiz:quiz_list' %}" class="btn btn-outline-secondary">Nevermind</a>
  </form>
{% endblock %}
