# Generated by Django 4.2.2 on 2023-06-11 12:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("quiz", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="answer",
            name="img",
            field=models.CharField(blank=True, max_length=250),
        ),
        migrations.AddField(
            model_name="question",
            name="img",
            field=models.CharField(blank=True, max_length=250),
        ),
        migrations.AddField(
            model_name="question",
            name="img_explanation",
            field=models.CharField(blank=True, max_length=250),
        ),
    ]
